@@ -4,10 +4,10 @@ import {join, basename, dirname, resolve, relative} from 'path';
 import url from 'url';
 
 // 要排除的目录列表
-const EXCLUDE_DIRS = ['.git', '.idea', 'soft', 'binary', 'pyTools', 'drop_code', 'jstest', 'local', 'logs', '对话1.txt', 'vod_cache', 'data/mv'];
+const EXCLUDE_DIRS = ['.git', '.idea', 'soft', 'plugins/pvideo', 'plugins/req-proxy', 'pyTools', 'drop_code', 'jstest', 'local', 'logs', '对话1.txt', 'vod_cache', 'data/mv'];
 
 // 要排除的文件列表
-const EXCLUDE_FILES = ['config/env.json', '.env', 'spider/js/UC分享.js', 'spider/js/百忙无果[官].js', 'json/UC分享.json', 'jx/奇奇.js', 'jx/芒果关姐.js', 'data/settings/link_data.json', 'index.json', 'custom.json'];
+const EXCLUDE_FILES = ['config/env.json', '.env', '.claude', 'clipboard.txt', 'clipboard.txt.bak', '.plugins.js', 'yarn.lock', 't4_daemon.pid', 'spider/js/UC分享.js', 'spider/js/百忙无果[官].js', 'json/UC分享.json', 'jx/奇奇.js', 'jx/芒果关姐.js', 'data/settings/link_data.json', 'index.json', 'custom.json'];
 
 // 获取脚本所在目录
 const getScriptDir = () => dirname(resolve(url.fileURLToPath(import.meta.url)));
